@@ -24,7 +24,7 @@ from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
 from calculate.lib.cl_ini_parser import iniParser
 from calculate.lib.utils.files import (isMount, readFile, find,
                                        FindFileType)
-from calculate.lib.utils.common import getValueFromCmdLine
+from calculate.lib.utils.common import getValueFromCmdLine, CmdlineParams
 from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.variables import user
 from calculate.lib.convertenv import convertEnv
@@ -81,7 +81,8 @@ class VariableClRemoteHostLive(ReadonlyVariable):
     """
 
     def get(self):
-        return getValueFromCmdLine("calculate", "domain") or ""
+        return getValueFromCmdLine(CmdlineParams.Calculate,
+                                   CmdlineParams.Domain) or ""
 
 
 class VariableOsRemoteAuth(Variable):
@@ -109,7 +110,8 @@ class VariableClRemotePw(Variable):
         self.help = _("specify the domain password")
 
     def get(self):
-        return getValueFromCmdLine("calculate", "domain_pw") or ""
+        return getValueFromCmdLine(CmdlineParams.Calculate,
+                                   CmdlineParams.DomainPassword) or ""
 
 
 class VariableClMovedSkipPath(Variable):
